@@ -27,7 +27,7 @@ makeHorizontalFacePredicate(double sliceCoord)
   using Element = typename GridView::Traits::template Codim<0>::Entity;
   auto predicate = [sliceCoord](const Element& element, unsigned int face) -> bool {
     const int dim = GridView::dimension;
-    const Dune::ReferenceElement<double,dim>& refElement = Dune::ReferenceElements<double, dim>::general(element.type());
+    const auto& refElement = Dune::ReferenceElements<double, dim>::general(element.type());
 
     int numVertices = refElement.size(face, 1, dim);
 
@@ -354,7 +354,7 @@ void test2d1dCoupling(double slice=0.0)
   testCoupling(glue);
 }
 
-int main(int argc, char *argv[]) try
+int main(int argc, char *argv[])
 {
   Dune::MPIHelper::instance(argc, argv);
 
@@ -434,7 +434,3 @@ int main(int argc, char *argv[]) try
 #endif
 
 }
-catch (Exception e) {
-  std::cout << e << std::endl;
-  return 1;
-}
